@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2016 Canonical
+ * Copyright (C) 2011-2017 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1626,7 +1626,6 @@ static void rapl_free_list(void)
 static const char *rapl_get_domain(const int n)
 {
 	int i;
-	static char buf[128];
 
 	rapl_info_t *rapl = rapl_list;
 
@@ -1635,6 +1634,8 @@ static const char *rapl_get_domain(const int n)
 	}
 	if (rapl) {
 		if (rapl->is_package) {
+			static char buf[128];
+
 			snprintf(buf, sizeof(buf), "pkg-%s", rapl->domain_name + 8);
 			return buf;
 		}
@@ -1852,9 +1853,10 @@ static int power_get_gpu_i915(
 		res->inaccurate[POWER_GPU] = true;
 		ret = -1;
 	} else {
-		s2->value[POWER_GPU] = (double)val / 1000000.0;
-		res->value[POWER_GPU] = stats_sane(s1, s2, POWER_GPU);
+		s2->value[POWER_GPU] = ((double)val / 1000000.0) / sample_delay;
+		s2->inaccurate[POWER_GPU] = false;
 		res->inaccurate[POWER_GPU] = false;
+		res->value[POWER_GPU] = stats_sane(s1, s2, POWER_GPU);
 		ret = 0;
 	}
 	return ret;
